/* midori-window.c generated by valac 0.38.8, the Vala compiler
 * generated from midori-window.vala, do not modify */

/*
 Copyright (C) 2015 Christian Dywan <christian@twotoasts.de>

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 See the file COPYING for the full license text.
*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gdk/gdk.h>
#include "webkit/webkit.h"


#define MIDORI_TYPE_WINDOW (midori_window_get_type ())
#define MIDORI_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MIDORI_TYPE_WINDOW, MidoriWindow))
#define MIDORI_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MIDORI_TYPE_WINDOW, MidoriWindowClass))
#define MIDORI_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MIDORI_TYPE_WINDOW))
#define MIDORI_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MIDORI_TYPE_WINDOW))
#define MIDORI_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MIDORI_TYPE_WINDOW, MidoriWindowClass))

typedef struct _MidoriWindow MidoriWindow;
typedef struct _MidoriWindowClass MidoriWindowClass;
typedef struct _MidoriWindowPrivate MidoriWindowPrivate;
enum  {
	MIDORI_WINDOW_0_PROPERTY,
	MIDORI_WINDOW_TOOLBAR_PROPERTY,
	MIDORI_WINDOW_ACTIONS_PROPERTY,
	MIDORI_WINDOW_CONTENTS_PROPERTY,
	MIDORI_WINDOW_SHOW_MENUBAR_PROPERTY,
	MIDORI_WINDOW_NUM_PROPERTIES
};
static GParamSpec* midori_window_properties[MIDORI_WINDOW_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _Block7Data Block7Data;
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

#define MIDORI_TYPE_SETTINGS (midori_settings_get_type ())
#define MIDORI_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MIDORI_TYPE_SETTINGS, MidoriSettings))
#define MIDORI_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MIDORI_TYPE_SETTINGS, MidoriSettingsClass))
#define MIDORI_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MIDORI_TYPE_SETTINGS))
#define MIDORI_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MIDORI_TYPE_SETTINGS))
#define MIDORI_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MIDORI_TYPE_SETTINGS, MidoriSettingsClass))

typedef struct _MidoriSettings MidoriSettings;
typedef struct _MidoriSettingsClass MidoriSettingsClass;
typedef struct _Block8Data Block8Data;

#define MIDORI_TYPE_PANED_ACTION (midori_paned_action_get_type ())
#define MIDORI_PANED_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MIDORI_TYPE_PANED_ACTION, MidoriPanedAction))
#define MIDORI_PANED_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MIDORI_TYPE_PANED_ACTION, MidoriPanedActionClass))
#define MIDORI_IS_PANED_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MIDORI_TYPE_PANED_ACTION))
#define MIDORI_IS_PANED_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MIDORI_TYPE_PANED_ACTION))
#define MIDORI_PANED_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MIDORI_TYPE_PANED_ACTION, MidoriPanedActionClass))

typedef struct _MidoriPanedAction MidoriPanedAction;
typedef struct _MidoriPanedActionClass MidoriPanedActionClass;
typedef struct _Block9Data Block9Data;
typedef struct _Block10Data Block10Data;
enum  {
	MIDORI_WINDOW_CONTEXT_MENU_SIGNAL,
	MIDORI_WINDOW_NUM_SIGNALS
};
static guint midori_window_signals[MIDORI_WINDOW_NUM_SIGNALS] = {0};

struct _MidoriWindow {
	GtkWindow parent_instance;
	MidoriWindowPrivate * priv;
};

struct _MidoriWindowClass {
	GtkWindowClass parent_class;
};

struct _MidoriWindowPrivate {
	GtkWidget* _toolbar;
	gchar* _actions;
	gchar* _extra_actions;
	GList* action_groups;
	GtkBox* box;
	GList* toolbars;
	GtkWidget* _contents;
	gboolean _show_menubar;
};

struct _Block7Data {
	int _ref_count_;
	MidoriWindow* self;
	GtkToolItem* toolitem;
	GtkAction* action;
};

struct _Block8Data {
	int _ref_count_;
	MidoriWindow* self;
	MidoriSettings* settings;
};

struct _Block9Data {
	int _ref_count_;
	MidoriWindow* self;
	GtkWidget* toolbar;
};

struct _Block10Data {
	int _ref_count_;
	MidoriWindow* self;
	GtkToolbar* toolbar;
};


static gpointer midori_window_parent_class = NULL;

GType midori_window_get_type (void) G_GNUC_CONST;
#define MIDORI_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), MIDORI_TYPE_WINDOW, MidoriWindowPrivate))
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
void midori_window_add_action_group (MidoriWindow* self, GtkActionGroup* action_group);
GtkWidget* midori_window_new (void);
GtkWidget* midori_window_construct (GType object_type);
GtkToolItem* midori_window_get_tool_item (MidoriWindow* self, const gchar* name);
static GtkToolItem* midori_window_create_tool_item (MidoriWindow* self, GtkAction* action);
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (void * _userdata_);
static gboolean __lambda22_ (Block7Data* _data7_, GdkEventButton* event);
static gboolean ___lambda22__gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
gboolean midori_window_get_show_menubar (MidoriWindow* self);
void midori_window_add_action (MidoriWindow* self, GtkAction* action);
static const gchar* midori_window_get_extra_actions (MidoriWindow* self);
static void midori_window_set_extra_actions (MidoriWindow* self, const gchar* value);
static void midori_window_update_toolbar (MidoriWindow* self);
void midori_window_remove_action (MidoriWindow* self, GtkAction* action);
const gchar* midori_window_get_actions (MidoriWindow* self);
GType midori_settings_get_type (void) G_GNUC_CONST;
static Block8Data* block8_data_ref (Block8Data* _data8_);
static void block8_data_unref (void * _userdata_);
GType midori_paned_action_get_type (void) G_GNUC_CONST;
MidoriPanedAction* midori_paned_action_new (void);
MidoriPanedAction* midori_paned_action_construct (GType object_type);
void midori_paned_action_set_child1 (MidoriPanedAction* self, GtkWidget* widget, const gchar* name, gboolean resize, gboolean shrink);
void midori_paned_action_set_child2 (MidoriPanedAction* self, GtkWidget* widget, const gchar* name, gboolean resize, gboolean shrink);
static void _____lambda23_ (Block8Data* _data8_, GdkRectangle* allocation);
static void ______lambda23__gtk_widget_size_allocate (GtkWidget* _sender, GdkRectangle* allocation, gpointer self);
gint midori_settings_get_search_width (MidoriSettings* self);
void midori_window_add_toolbar (MidoriWindow* self, GtkWidget* toolbar);
static Block9Data* block9_data_ref (Block9Data* _data9_);
static void block9_data_unref (void * _userdata_);
static gboolean ___lambda24_ (Block9Data* _data9_, gint x, gint y, gint button);
static gboolean ____lambda24__gtk_toolbar_popup_context_menu (GtkToolbar* _sender, gint x, gint y, gint button_number, gpointer self);
GtkWidget* midori_window_get_toolbar (MidoriWindow* self);
static Block10Data* block10_data_ref (Block10Data* _data10_);
static void block10_data_unref (void * _userdata_);
static gboolean _midori_window_toolbar____lambda25_ (Block10Data* _data10_, gint x, gint y, gint button);
static gboolean __midori_window_toolbar____lambda25__gtk_toolbar_popup_context_menu (GtkToolbar* _sender, gint x, gint y, gint button_number, gpointer self);
void midori_window_set_actions (MidoriWindow* self, const gchar* value);
GtkWidget* midori_window_get_contents (MidoriWindow* self);
void midori_window_set_contents (MidoriWindow* self, GtkWidget* value);
void midori_window_set_show_menubar (MidoriWindow* self, gboolean value);
static void g_cclosure_user_marshal_BOOLEAN__OBJECT_OBJECT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static GObject * midori_window_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _midori_window___lambda26_ (MidoriWindow* self, GParamSpec* pspec);
static void __midori_window___lambda26__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void midori_window_finalize (GObject * obj);
static void _vala_midori_window_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_midori_window_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static void _g_object_unref0_ (gpointer var) {
#line 42 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 188 "midori-window.c"
}


static inline void _g_list_free__g_object_unref0_ (GList* self) {
#line 42 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
#line 195 "midori-window.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 60 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return self ? g_object_ref (self) : NULL;
#line 202 "midori-window.c"
}


void midori_window_add_action_group (MidoriWindow* self, GtkActionGroup* action_group) {
	GtkActionGroup* _tmp0_;
	GtkActionGroup* _tmp1_;
#line 59 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (self != NULL);
#line 59 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (action_group != NULL);
#line 60 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = action_group;
#line 60 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 60 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self->priv->action_groups = g_list_append (self->priv->action_groups, _tmp1_);
#line 219 "midori-window.c"
}


GtkWidget* midori_window_construct (GType object_type) {
	MidoriWindow * self = NULL;
#line 66 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self = (MidoriWindow*) g_object_new (object_type, NULL);
#line 66 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return (GtkWidget*) self;
#line 229 "midori-window.c"
}


GtkWidget* midori_window_new (void) {
#line 66 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return midori_window_construct (MIDORI_TYPE_WINDOW);
#line 236 "midori-window.c"
}


GtkToolItem* midori_window_get_tool_item (MidoriWindow* self, const gchar* name) {
	GtkToolItem* result = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GList* _tmp2_;
	const gchar* _tmp10_;
#line 69 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 69 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 71 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = name;
#line 71 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (g_strcmp0 (_tmp0_, "") == 0) {
#line 72 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		result = NULL;
#line 72 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		return result;
#line 258 "midori-window.c"
	}
#line 74 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = name;
#line 74 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (g_strcmp0 (_tmp1_, "TabNew") == 0) {
#line 75 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		result = NULL;
#line 75 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		return result;
#line 268 "midori-window.c"
	}
#line 76 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp2_ = self->priv->action_groups;
#line 272 "midori-window.c"
	{
		GList* action_group_collection = NULL;
		GList* action_group_it = NULL;
#line 76 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		action_group_collection = _tmp2_;
#line 76 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		for (action_group_it = action_group_collection; action_group_it != NULL; action_group_it = action_group_it->next) {
#line 280 "midori-window.c"
			GtkActionGroup* action_group = NULL;
#line 76 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
			action_group = (GtkActionGroup*) action_group_it->data;
#line 284 "midori-window.c"
			{
				GtkAction* action = NULL;
				GtkActionGroup* _tmp3_;
				const gchar* _tmp4_;
				GtkAction* _tmp5_;
				GtkAction* _tmp6_;
				GtkAction* _tmp7_;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp3_ = action_group;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp4_ = name;
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp5_ = gtk_action_group_get_action (_tmp3_, _tmp4_);
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp6_ = _g_object_ref0 (_tmp5_);
#line 77 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				action = _tmp6_;
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp7_ = action;
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				if (_tmp7_ != NULL) {
#line 306 "midori-window.c"
					GtkAction* _tmp8_;
					GtkToolItem* _tmp9_;
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp8_ = action;
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp9_ = midori_window_create_tool_item (self, _tmp8_);
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					result = _tmp9_;
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_g_object_unref0 (action);
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					return result;
#line 319 "midori-window.c"
				}
#line 76 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_g_object_unref0 (action);
#line 323 "midori-window.c"
			}
		}
	}
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp10_ = name;
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_warning ("midori-window.vala:82: Action %s not known to Window", _tmp10_);
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	result = NULL;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return result;
#line 335 "midori-window.c"
}


static Block7Data* block7_data_ref (Block7Data* _data7_) {
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_atomic_int_inc (&_data7_->_ref_count_);
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return _data7_;
#line 344 "midori-window.c"
}


static void block7_data_unref (void * _userdata_) {
	Block7Data* _data7_;
	_data7_ = (Block7Data*) _userdata_;
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
#line 353 "midori-window.c"
		MidoriWindow* self;
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		self = _data7_->self;
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_object_unref0 (_data7_->toolitem);
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_object_unref0 (_data7_->action);
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_object_unref0 (self);
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_slice_free (Block7Data, _data7_);
#line 365 "midori-window.c"
	}
}


static gboolean __lambda22_ (Block7Data* _data7_, GdkEventButton* event) {
	MidoriWindow* self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GdkEventButton _tmp1_;
	guint _tmp2_;
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self = _data7_->self;
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = *event;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp2_ = _tmp1_.button;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (_tmp2_ == ((guint) 3)) {
#line 386 "midori-window.c"
		GtkToolItem* _tmp3_;
		GtkAction* _tmp4_;
		gboolean _tmp5_ = FALSE;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp3_ = _data7_->toolitem;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp4_ = _data7_->action;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_signal_emit (self, midori_window_signals[MIDORI_WINDOW_CONTEXT_MENU_SIGNAL], 0, (GtkWidget*) _tmp3_, _tmp4_, &_tmp5_);
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp0_ = _tmp5_;
#line 398 "midori-window.c"
	} else {
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp0_ = FALSE;
#line 402 "midori-window.c"
	}
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	result = _tmp0_;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return result;
#line 408 "midori-window.c"
}


static gboolean ___lambda22__gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = __lambda22_ (self, event);
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return result;
#line 417 "midori-window.c"
}


static GtkToolItem* midori_window_create_tool_item (MidoriWindow* self, GtkAction* action) {
	GtkToolItem* result = NULL;
	Block7Data* _data7_;
	GtkAction* _tmp0_;
	GtkAction* _tmp1_;
	GtkAction* _tmp2_;
	GtkWidget* _tmp3_;
	GtkToolItem* _tmp4_;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	GtkAction* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	GtkToolItem* _tmp17_;
	GtkWidget* _tmp18_;
	GtkAction* _tmp19_;
	const gchar* _tmp20_;
	const gchar* _tmp21_;
	GtkToolItem* _tmp25_;
	GtkToolItem* _tmp26_;
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_val_if_fail (action != NULL, NULL);
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_data7_ = g_slice_new0 (Block7Data);
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_data7_->_ref_count_ = 1;
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_data7_->self = g_object_ref (self);
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = action;
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_object_unref0 (_data7_->action);
#line 86 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_data7_->action = _tmp1_;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp2_ = _data7_->action;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp3_ = gtk_action_create_tool_item (_tmp2_);
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GTK_TYPE_TOOL_ITEM, GtkToolItem));
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_data7_->toolitem = _tmp4_;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp7_ = _data7_->action;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp8_ = gtk_action_get_icon_name (_tmp7_);
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp9_ = _tmp8_;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (_tmp9_ == NULL) {
#line 475 "midori-window.c"
		GtkAction* _tmp10_;
		const gchar* _tmp11_;
		const gchar* _tmp12_;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp10_ = _data7_->action;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp11_ = gtk_action_get_stock_id (_tmp10_);
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp12_ = _tmp11_;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp6_ = _tmp12_ == NULL;
#line 487 "midori-window.c"
	} else {
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp6_ = FALSE;
#line 491 "midori-window.c"
	}
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (_tmp6_) {
#line 495 "midori-window.c"
		GtkAction* _tmp13_;
		GIcon* _tmp14_;
		GIcon* _tmp15_;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp13_ = _data7_->action;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp14_ = gtk_action_get_gicon (_tmp13_);
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp15_ = _tmp14_;
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp5_ = _tmp15_ == NULL;
#line 507 "midori-window.c"
	} else {
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp5_ = FALSE;
#line 511 "midori-window.c"
	}
#line 89 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (_tmp5_) {
#line 515 "midori-window.c"
		GtkToolItem* _tmp16_;
#line 90 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp16_ = _data7_->toolitem;
#line 90 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		gtk_tool_item_set_is_important (_tmp16_, TRUE);
#line 521 "midori-window.c"
	}
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp17_ = _data7_->toolitem;
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp18_ = gtk_bin_get_child ((GtkBin*) _tmp17_);
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_signal_connect_data (_tmp18_, "button-press-event", (GCallback) ___lambda22__gtk_widget_button_press_event, block7_data_ref (_data7_), (GClosureNotify) block7_data_unref, 0);
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp19_ = _data7_->action;
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp20_ = gtk_action_get_name (_tmp19_);
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp21_ = _tmp20_;
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (g_strcmp0 (_tmp21_, "CompactMenu") == 0) {
#line 537 "midori-window.c"
		GtkToolItem* _tmp22_;
		gboolean _tmp23_;
		GtkToolItem* _tmp24_;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp22_ = _data7_->toolitem;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp23_ = self->priv->_show_menubar;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp22_, !_tmp23_);
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp24_ = _data7_->toolitem;
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_object_bind_property_with_closures ((GObject*) self, "show-menubar", (GObject*) _tmp24_, "visible", G_BINDING_DEFAULT | G_BINDING_INVERT_BOOLEAN, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
#line 551 "midori-window.c"
	}
#line 99 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp25_ = _data7_->toolitem;
#line 99 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp26_ = _g_object_ref0 (_tmp25_);
#line 99 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	result = _tmp26_;
#line 99 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	block7_data_unref (_data7_);
#line 99 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_data7_ = NULL;
#line 99 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return result;
#line 565 "midori-window.c"
}


/**
         * Adds an action to the (browser) window.
         * Typically it will be displayed in the primary toolbar or headerbar.
         *
         * If @action is a ContextAction a menu will be displayed.
         *
         * Since: 0.6.0
         **/
void midori_window_add_action (MidoriWindow* self, GtkAction* action) {
	GList* _tmp0_;
	gconstpointer _tmp1_;
	GtkAction* _tmp2_;
	const gchar* _tmp3_;
	GtkAction* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
#line 110 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (self != NULL);
#line 110 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (action != NULL);
#line 111 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = self->priv->action_groups;
#line 111 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = g_list_nth_data (_tmp0_, (guint) 0);
#line 111 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp2_ = action;
#line 111 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	gtk_action_group_add_action ((GtkActionGroup*) _tmp1_, _tmp2_);
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp3_ = self->priv->_extra_actions;
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp4_ = action;
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp5_ = gtk_action_get_name (_tmp4_);
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp6_ = _tmp5_;
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp7_ = g_strconcat (",", _tmp6_, NULL);
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp8_ = _tmp7_;
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp9_ = g_strconcat (_tmp3_, _tmp8_, NULL);
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp10_ = _tmp9_;
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	midori_window_set_extra_actions (self, _tmp10_);
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_free0 (_tmp10_);
#line 112 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_free0 (_tmp8_);
#line 113 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	midori_window_update_toolbar (self);
#line 625 "midori-window.c"
}


/**
         * Remove an action from the (browser) window.
         *
         * Since: 0.6.0
         **/
static gchar* string_replace (const gchar* self, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError * _inner_error_ = NULL;
#line 1415 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1415 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (old != NULL, NULL);
#line 1415 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	if ((*((gchar*) self)) == '\0') {
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 649 "midori-window.c"
	} else {
		const gchar* _tmp2_;
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp2_ = old;
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp1_ = (*((gchar*) _tmp2_)) == '\0';
#line 656 "midori-window.c"
	}
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp0_ = TRUE;
#line 662 "midori-window.c"
	} else {
		const gchar* _tmp3_;
		const gchar* _tmp4_;
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp3_ = old;
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp4_ = replacement;
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp0_ = g_strcmp0 (_tmp3_, _tmp4_) == 0;
#line 672 "midori-window.c"
	}
#line 1416 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 676 "midori-window.c"
		gchar* _tmp5_;
#line 1417 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp5_ = g_strdup (self);
#line 1417 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		result = _tmp5_;
#line 1417 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		return result;
#line 684 "midori-window.c"
	}
	{
		GRegex* regex = NULL;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		GRegex* _tmp9_;
		GRegex* _tmp10_;
		gchar* _tmp11_ = NULL;
		GRegex* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp6_ = old;
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp7_ = g_regex_escape_string (_tmp6_, -1);
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp8_ = _tmp7_;
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp9_ = g_regex_new (_tmp8_, 0, 0, &_inner_error_);
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp10_ = _tmp9_;
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_g_free0 (_tmp8_);
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		regex = _tmp10_;
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 716 "midori-window.c"
				goto __catch38_g_regex_error;
			}
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1420 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			return NULL;
#line 725 "midori-window.c"
		}
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp12_ = regex;
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp13_ = replacement;
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp14_ = g_regex_replace_literal (_tmp12_, self, (gssize) -1, 0, _tmp13_, 0, &_inner_error_);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp11_ = _tmp14_;
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 741 "midori-window.c"
				goto __catch38_g_regex_error;
			}
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
			return NULL;
#line 752 "midori-window.c"
		}
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp15_ = _tmp11_;
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_tmp11_ = NULL;
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		result = _tmp15_;
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_g_free0 (_tmp11_);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_g_regex_unref0 (regex);
#line 1421 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		return result;
#line 766 "midori-window.c"
	}
	goto __finally38;
	__catch38_g_regex_error:
	{
		GError* e = NULL;
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		e = _inner_error_;
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_inner_error_ = NULL;
#line 1423 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		g_assert_not_reached ();
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		_g_error_free0 (e);
#line 780 "midori-window.c"
	}
	__finally38:
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		g_clear_error (&_inner_error_);
#line 1419 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
		return NULL;
#line 791 "midori-window.c"
	}
}


void midori_window_remove_action (MidoriWindow* self, GtkAction* action) {
	GList* _tmp0_;
	gconstpointer _tmp1_;
	GtkAction* _tmp2_;
	const gchar* _tmp3_;
	GtkAction* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
#line 121 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (self != NULL);
#line 121 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (action != NULL);
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = self->priv->action_groups;
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = g_list_nth_data (_tmp0_, (guint) 0);
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp2_ = action;
#line 122 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	gtk_action_group_remove_action ((GtkActionGroup*) _tmp1_, _tmp2_);
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp3_ = self->priv->_extra_actions;
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp4_ = action;
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp5_ = gtk_action_get_name (_tmp4_);
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp6_ = _tmp5_;
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp7_ = g_strconcat (",", _tmp6_, NULL);
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp8_ = _tmp7_;
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp9_ = string_replace (_tmp3_, _tmp8_, "");
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp10_ = _tmp9_;
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	midori_window_set_extra_actions (self, _tmp10_);
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_free0 (_tmp10_);
#line 123 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_free0 (_tmp8_);
#line 124 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	midori_window_update_toolbar (self);
#line 844 "midori-window.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1411 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1411 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1412 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1412 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1412 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1412 "/usr/share/vala-0.38/vapi/glib-2.0.vapi"
	return result;
#line 864 "midori-window.c"
}


static Block8Data* block8_data_ref (Block8Data* _data8_) {
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_atomic_int_inc (&_data8_->_ref_count_);
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return _data8_;
#line 873 "midori-window.c"
}


static void block8_data_unref (void * _userdata_) {
	Block8Data* _data8_;
	_data8_ = (Block8Data*) _userdata_;
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (g_atomic_int_dec_and_test (&_data8_->_ref_count_)) {
#line 882 "midori-window.c"
		MidoriWindow* self;
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		self = _data8_->self;
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_object_unref0 (_data8_->settings);
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_object_unref0 (self);
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_slice_free (Block8Data, _data8_);
#line 892 "midori-window.c"
	}
}


static void _____lambda23_ (Block8Data* _data8_, GdkRectangle* allocation) {
	MidoriWindow* self;
	MidoriSettings* _tmp0_;
	GdkRectangle _tmp1_;
	gint _tmp2_;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self = _data8_->self;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (allocation != NULL);
#line 196 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = _data8_->settings;
#line 196 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = *allocation;
#line 196 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp2_ = _tmp1_.width;
#line 196 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_object_set ((GObject*) _tmp0_, "search-width", _tmp2_, NULL);
#line 914 "midori-window.c"
}


static void ______lambda23__gtk_widget_size_allocate (GtkWidget* _sender, GdkRectangle* allocation, gpointer self) {
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_____lambda23_ (self, allocation);
#line 921 "midori-window.c"
}


static void midori_window_update_toolbar (MidoriWindow* self) {
	GtkContainer* container = NULL;
	GtkWidget* _tmp0_;
	GtkContainer* _tmp1_;
	GtkContainer* _tmp2_;
	GList* _tmp3_;
	gchar* all_actions = NULL;
	const gchar* _tmp6_;
	gboolean _tmp7_;
	gchar** names = NULL;
	const gchar* _tmp20_;
	gchar** _tmp21_;
	gchar** _tmp22_;
	gint names_length1;
	gint _names_size_;
	GtkToolbar* toolbar = NULL;
	GtkWidget* _tmp23_;
	GtkToolbar* _tmp24_;
	gchar* previous = NULL;
	GtkToolItem* toolitem_previous = NULL;
	gchar** _tmp25_;
	gint _tmp25__length1;
#line 127 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (self != NULL);
#line 128 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = self->priv->_toolbar;
#line 128 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GTK_TYPE_CONTAINER, GtkContainer));
#line 128 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	container = _tmp1_;
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp2_ = container;
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp3_ = gtk_container_get_children (_tmp2_);
#line 959 "midori-window.c"
	{
		GList* toolitem_collection = NULL;
		GList* toolitem_it = NULL;
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		toolitem_collection = _tmp3_;
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		for (toolitem_it = toolitem_collection; toolitem_it != NULL; toolitem_it = toolitem_it->next) {
#line 967 "midori-window.c"
			GtkWidget* toolitem = NULL;
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
			toolitem = (GtkWidget*) toolitem_it->data;
#line 971 "midori-window.c"
			{
				GtkContainer* _tmp4_;
				GtkWidget* _tmp5_;
#line 130 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp4_ = container;
#line 130 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp5_ = toolitem;
#line 130 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				gtk_container_remove (_tmp4_, _tmp5_);
#line 981 "midori-window.c"
			}
		}
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_list_free0 (toolitem_collection);
#line 986 "midori-window.c"
	}
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp6_ = self->priv->_actions;
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp7_ = string_contains (_tmp6_, "CompactMenu");
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (_tmp7_) {
#line 994 "midori-window.c"
		const gchar* _tmp8_;
		const gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp8_ = self->priv->_actions;
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp9_ = self->priv->_extra_actions;
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp10_ = g_strconcat (_tmp9_, ",CompactMenu", NULL);
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp11_ = _tmp10_;
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp12_ = string_replace (_tmp8_, "CompactMenu", _tmp11_);
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_free0 (all_actions);
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		all_actions = _tmp12_;
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_free0 (_tmp11_);
#line 1016 "midori-window.c"
	} else {
		const gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		const gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp13_ = self->priv->_actions;
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp14_ = g_strconcat (_tmp13_, ",", NULL);
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp15_ = _tmp14_;
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp16_ = self->priv->_extra_actions;
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp17_ = g_strconcat (_tmp15_, _tmp16_, NULL);
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp18_ = _tmp17_;
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp19_ = g_strconcat (_tmp18_, ",CompactMenu", NULL);
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_free0 (all_actions);
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		all_actions = _tmp19_;
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_free0 (_tmp18_);
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_free0 (_tmp15_);
#line 1047 "midori-window.c"
	}
#line 138 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp20_ = all_actions;
#line 138 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp22_ = _tmp21_ = g_strsplit (_tmp20_, ",", 0);
#line 138 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	names = _tmp22_;
#line 138 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	names_length1 = _vala_array_length (_tmp21_);
#line 138 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_names_size_ = names_length1;
#line 177 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp23_ = self->priv->_toolbar;
#line 177 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp24_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GTK_TYPE_TOOLBAR, GtkToolbar));
#line 177 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	toolbar = _tmp24_;
#line 178 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	previous = NULL;
#line 179 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	toolitem_previous = NULL;
#line 180 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp25_ = names;
#line 180 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp25__length1 = names_length1;
#line 1073 "midori-window.c"
	{
		gchar** name_collection = NULL;
		gint name_collection_length1 = 0;
		gint _name_collection_size_ = 0;
		gint name_it = 0;
#line 180 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		name_collection = _tmp25_;
#line 180 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		name_collection_length1 = _tmp25__length1;
#line 180 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		for (name_it = 0; name_it < _tmp25__length1; name_it = name_it + 1) {
#line 1085 "midori-window.c"
			const gchar* name = NULL;
#line 180 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
			name = name_collection[name_it];
#line 1089 "midori-window.c"
			{
				GtkToolItem* toolitem = NULL;
				const gchar* _tmp26_;
				GtkToolItem* _tmp27_;
				GtkToolItem* _tmp28_;
				gboolean _tmp29_ = FALSE;
				gboolean _tmp30_ = FALSE;
				const gchar* _tmp31_;
				GtkToolbar* _tmp71_;
				GtkToolItem* _tmp72_;
#line 181 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp26_ = name;
#line 181 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp27_ = midori_window_get_tool_item (self, _tmp26_);
#line 181 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				toolitem = _tmp27_;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp28_ = toolitem;
#line 182 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				if (_tmp28_ == NULL) {
#line 183 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_g_object_unref0 (toolitem);
#line 183 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					continue;
#line 1114 "midori-window.c"
				}
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp31_ = name;
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				if (g_strcmp0 (_tmp31_, "Location") == 0) {
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp30_ = TRUE;
#line 1122 "midori-window.c"
				} else {
					const gchar* _tmp32_;
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp32_ = name;
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp30_ = g_strcmp0 (_tmp32_, "Search") == 0;
#line 1129 "midori-window.c"
				}
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				if (_tmp30_) {
#line 1133 "midori-window.c"
					gboolean _tmp33_ = FALSE;
					const gchar* _tmp34_;
#line 185 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp34_ = previous;
#line 185 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					if (g_strcmp0 (_tmp34_, "Location") == 0) {
#line 185 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
						_tmp33_ = TRUE;
#line 1142 "midori-window.c"
					} else {
						const gchar* _tmp35_;
#line 185 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
						_tmp35_ = previous;
#line 185 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
						_tmp33_ = g_strcmp0 (_tmp35_, "Search") == 0;
#line 1149 "midori-window.c"
					}
#line 185 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp29_ = _tmp33_;
#line 1153 "midori-window.c"
				} else {
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp29_ = FALSE;
#line 1157 "midori-window.c"
				}
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				if (_tmp29_) {
#line 1161 "midori-window.c"
					Block8Data* _data8_;
					GtkToolItem* _tmp36_;
					GtkToolbar* _tmp37_;
					GtkToolItem* _tmp38_;
					MidoriPanedAction* paned = NULL;
					MidoriPanedAction* _tmp39_;
					MidoriPanedAction* _tmp40_;
					GtkToolItem* _tmp41_;
					const gchar* _tmp42_;
					const gchar* _tmp43_;
					MidoriPanedAction* _tmp44_;
					GtkToolItem* _tmp45_;
					const gchar* _tmp46_;
					const gchar* _tmp47_;
					GtkToolItem* _tmp48_ = NULL;
					const gchar* _tmp49_;
					GtkToolItem* sizeable = NULL;
					GtkToolItem* _tmp52_;
					GtkToolItem* _tmp53_;
					GtkToolItem* _tmp54_ = NULL;
					const gchar* _tmp55_;
					GtkToolItem* requester = NULL;
					GtkToolItem* _tmp58_;
					GtkToolItem* _tmp59_;
					MidoriSettings* _tmp60_;
					gint _tmp61_;
					gint _tmp62_;
					MidoriPanedAction* _tmp63_;
					GtkWidget* _tmp64_;
					GtkToolItem* _tmp65_;
					GtkToolItem* _tmp66_;
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_data8_ = g_slice_new0 (Block8Data);
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_data8_->_ref_count_ = 1;
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_data8_->self = g_object_ref (self);
#line 186 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp36_ = toolitem_previous;
#line 186 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					g_object_ref ((GObject*) _tmp36_);
#line 187 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp37_ = toolbar;
#line 187 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp38_ = toolitem_previous;
#line 187 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					gtk_container_remove ((GtkContainer*) _tmp37_, (GtkWidget*) _tmp38_);
#line 188 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp39_ = midori_paned_action_new ();
#line 188 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					paned = _tmp39_;
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp40_ = paned;
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp41_ = toolitem_previous;
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp42_ = previous;
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp43_ = previous;
#line 189 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					midori_paned_action_set_child1 (_tmp40_, (GtkWidget*) _tmp41_, _tmp42_, g_strcmp0 (_tmp43_, "Search") != 0, TRUE);
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp44_ = paned;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp45_ = toolitem;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp46_ = name;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp47_ = name;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					midori_paned_action_set_child2 (_tmp44_, (GtkWidget*) _tmp45_, _tmp46_, g_strcmp0 (_tmp47_, "Search") != 0, TRUE);
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_data8_->settings = NULL;
#line 193 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					g_object_get ((GObject*) self, "settings", &_data8_->settings, NULL);
#line 194 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp49_ = name;
#line 194 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					if (g_strcmp0 (_tmp49_, "Search") == 0) {
#line 1241 "midori-window.c"
						GtkToolItem* _tmp50_;
#line 194 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
						_tmp50_ = toolitem;
#line 194 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
						_tmp48_ = _tmp50_;
#line 1247 "midori-window.c"
					} else {
						GtkToolItem* _tmp51_;
#line 194 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
						_tmp51_ = toolitem_previous;
#line 194 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
						_tmp48_ = _tmp51_;
#line 1254 "midori-window.c"
					}
#line 194 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp52_ = _g_object_ref0 (_tmp48_);
#line 194 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					sizeable = _tmp52_;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp53_ = sizeable;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					g_signal_connect_data ((GtkWidget*) _tmp53_, "size-allocate", (GCallback) ______lambda23__gtk_widget_size_allocate, block8_data_ref (_data8_), (GClosureNotify) block8_data_unref, 0);
#line 198 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp55_ = previous;
#line 198 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					if (g_strcmp0 (_tmp55_, "Search") == 0) {
#line 1268 "midori-window.c"
						GtkToolItem* _tmp56_;
#line 198 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
						_tmp56_ = toolitem_previous;
#line 198 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
						_tmp54_ = _tmp56_;
#line 1274 "midori-window.c"
					} else {
						GtkToolItem* _tmp57_;
#line 198 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
						_tmp57_ = toolitem;
#line 198 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
						_tmp54_ = _tmp57_;
#line 1281 "midori-window.c"
					}
#line 198 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp58_ = _g_object_ref0 (_tmp54_);
#line 198 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					requester = _tmp58_;
#line 199 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp59_ = requester;
#line 199 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp60_ = _data8_->settings;
#line 199 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp61_ = midori_settings_get_search_width (_tmp60_);
#line 199 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp62_ = _tmp61_;
#line 199 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					gtk_widget_set_size_request ((GtkWidget*) _tmp59_, _tmp62_, -1);
#line 200 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp63_ = paned;
#line 200 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp64_ = gtk_action_create_tool_item ((GtkAction*) _tmp63_);
#line 200 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp65_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, GTK_TYPE_TOOL_ITEM, GtkToolItem));
#line 200 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_g_object_unref0 (toolitem);
#line 200 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					toolitem = _tmp65_;
#line 201 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_g_free0 (previous);
#line 201 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					previous = NULL;
#line 202 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp66_ = toolitem_previous;
#line 202 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					g_object_unref ((GObject*) _tmp66_);
#line 203 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_g_object_unref0 (toolitem_previous);
#line 203 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					toolitem_previous = NULL;
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_g_object_unref0 (requester);
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_g_object_unref0 (sizeable);
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_g_object_unref0 (paned);
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					block8_data_unref (_data8_);
#line 184 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_data8_ = NULL;
#line 1329 "midori-window.c"
				} else {
					const gchar* _tmp67_;
					gchar* _tmp68_;
					GtkToolItem* _tmp69_;
					GtkToolItem* _tmp70_;
#line 205 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp67_ = name;
#line 205 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp68_ = g_strdup (_tmp67_);
#line 205 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_g_free0 (previous);
#line 205 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					previous = _tmp68_;
#line 206 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp69_ = toolitem;
#line 206 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp70_ = _g_object_ref0 (_tmp69_);
#line 206 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_g_object_unref0 (toolitem_previous);
#line 206 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					toolitem_previous = _tmp70_;
#line 1351 "midori-window.c"
				}
#line 208 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp71_ = toolbar;
#line 208 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp72_ = toolitem;
#line 208 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				gtk_toolbar_insert (_tmp71_, _tmp72_, -1);
#line 180 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_g_object_unref0 (toolitem);
#line 1361 "midori-window.c"
			}
		}
	}
#line 127 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_object_unref0 (toolitem_previous);
#line 127 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_free0 (previous);
#line 127 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_object_unref0 (toolbar);
#line 127 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	names = (_vala_array_free (names, names_length1, (GDestroyNotify) g_free), NULL);
#line 127 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_free0 (all_actions);
#line 127 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_object_unref0 (container);
#line 1377 "midori-window.c"
}


static Block9Data* block9_data_ref (Block9Data* _data9_) {
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_atomic_int_inc (&_data9_->_ref_count_);
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return _data9_;
#line 1386 "midori-window.c"
}


static void block9_data_unref (void * _userdata_) {
	Block9Data* _data9_;
	_data9_ = (Block9Data*) _userdata_;
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (g_atomic_int_dec_and_test (&_data9_->_ref_count_)) {
#line 1395 "midori-window.c"
		MidoriWindow* self;
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		self = _data9_->self;
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_object_unref0 (_data9_->toolbar);
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_object_unref0 (self);
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_slice_free (Block9Data, _data9_);
#line 1405 "midori-window.c"
	}
}


static gboolean ___lambda24_ (Block9Data* _data9_, gint x, gint y, gint button) {
	MidoriWindow* self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gint _tmp1_;
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self = _data9_->self;
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = button;
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (_tmp1_ == 3) {
#line 1421 "midori-window.c"
		GtkWidget* _tmp2_;
		gboolean _tmp3_ = FALSE;
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp2_ = _data9_->toolbar;
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_signal_emit (self, midori_window_signals[MIDORI_WINDOW_CONTEXT_MENU_SIGNAL], 0, _tmp2_, NULL, &_tmp3_);
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp0_ = _tmp3_;
#line 1430 "midori-window.c"
	} else {
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp0_ = FALSE;
#line 1434 "midori-window.c"
	}
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	result = _tmp0_;
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return result;
#line 1440 "midori-window.c"
}


static gboolean ____lambda24__gtk_toolbar_popup_context_menu (GtkToolbar* _sender, gint x, gint y, gint button_number, gpointer self) {
	gboolean result;
	result = ___lambda24_ (self, x, y, button_number);
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return result;
#line 1449 "midori-window.c"
}


void midori_window_add_toolbar (MidoriWindow* self, GtkWidget* toolbar) {
	Block9Data* _data9_;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	GtkToolbar* _toolbar = NULL;
	GtkWidget* _tmp2_;
	GtkToolbar* _tmp3_;
	GtkToolbar* _tmp4_;
	GtkBox* _tmp6_;
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (self != NULL);
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (toolbar != NULL);
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_data9_ = g_slice_new0 (Block9Data);
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_data9_->_ref_count_ = 1;
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_data9_->self = g_object_ref (self);
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = toolbar;
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_object_unref0 (_data9_->toolbar);
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_data9_->toolbar = _tmp1_;
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp2_ = _data9_->toolbar;
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GTK_TYPE_TOOLBAR) ? ((GtkToolbar*) _tmp2_) : NULL);
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_toolbar = _tmp3_;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp4_ = _toolbar;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (_tmp4_ != NULL) {
#line 1490 "midori-window.c"
		GtkToolbar* _tmp5_;
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp5_ = _toolbar;
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_signal_connect_data (_tmp5_, "popup-context-menu", (GCallback) ____lambda24__gtk_toolbar_popup_context_menu, block9_data_ref (_data9_), (GClosureNotify) block9_data_unref, 0);
#line 1496 "midori-window.c"
	}
#line 222 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp6_ = self->priv->box;
#line 222 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (_tmp6_ == NULL) {
#line 1502 "midori-window.c"
		GtkWidget* _tmp7_;
		GtkWidget* _tmp8_;
#line 223 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp7_ = _data9_->toolbar;
#line 223 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp8_ = _g_object_ref0 (_tmp7_);
#line 223 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		self->priv->toolbars = g_list_append (self->priv->toolbars, _tmp8_);
#line 1511 "midori-window.c"
	} else {
		GtkBox* _tmp9_;
		GtkWidget* _tmp10_;
#line 225 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp9_ = self->priv->box;
#line 225 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp10_ = _data9_->toolbar;
#line 225 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		gtk_box_pack_start (_tmp9_, _tmp10_, FALSE, FALSE, (guint) 0);
#line 1521 "midori-window.c"
	}
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_object_unref0 (_toolbar);
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	block9_data_unref (_data9_);
#line 212 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_data9_ = NULL;
#line 1529 "midori-window.c"
}


static Block10Data* block10_data_ref (Block10Data* _data10_) {
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_atomic_int_inc (&_data10_->_ref_count_);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return _data10_;
#line 1538 "midori-window.c"
}


static void block10_data_unref (void * _userdata_) {
	Block10Data* _data10_;
	_data10_ = (Block10Data*) _userdata_;
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (g_atomic_int_dec_and_test (&_data10_->_ref_count_)) {
#line 1547 "midori-window.c"
		MidoriWindow* self;
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		self = _data10_->self;
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_object_unref0 (_data10_->toolbar);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_object_unref0 (self);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_slice_free (Block10Data, _data10_);
#line 1557 "midori-window.c"
	}
}


static gboolean _midori_window_toolbar____lambda25_ (Block10Data* _data10_, gint x, gint y, gint button) {
	MidoriWindow* self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gint _tmp1_;
#line 33 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self = _data10_->self;
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = button;
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (_tmp1_ == 3) {
#line 1573 "midori-window.c"
		GtkToolbar* _tmp2_;
		gboolean _tmp3_ = FALSE;
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp2_ = _data10_->toolbar;
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_signal_emit (self, midori_window_signals[MIDORI_WINDOW_CONTEXT_MENU_SIGNAL], 0, (GtkWidget*) _tmp2_, NULL, &_tmp3_);
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp0_ = _tmp3_;
#line 1582 "midori-window.c"
	} else {
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp0_ = FALSE;
#line 1586 "midori-window.c"
	}
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	result = _tmp0_;
#line 34 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return result;
#line 1592 "midori-window.c"
}


static gboolean __midori_window_toolbar____lambda25__gtk_toolbar_popup_context_menu (GtkToolbar* _sender, gint x, gint y, gint button_number, gpointer self) {
	gboolean result;
	result = _midori_window_toolbar____lambda25_ (self, x, y, button_number);
#line 33 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return result;
#line 1601 "midori-window.c"
}


GtkWidget* midori_window_get_toolbar (MidoriWindow* self) {
	GtkWidget* result;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp6_;
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = self->priv->_toolbar;
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (_tmp0_ == NULL) {
#line 1615 "midori-window.c"
		Block10Data* _data10_;
		GtkToolbar* _tmp1_;
		GtkToolbar* _tmp2_;
		GtkToolbar* _tmp3_;
		GtkToolbar* _tmp4_;
		GtkWidget* _tmp5_;
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_data10_ = g_slice_new0 (Block10Data);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_data10_->_ref_count_ = 1;
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_data10_->self = g_object_ref (self);
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp1_ = (GtkToolbar*) gtk_toolbar_new ();
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_object_ref_sink (_tmp1_);
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_data10_->toolbar = _tmp1_;
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp2_ = _data10_->toolbar;
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		gtk_toolbar_set_show_arrow (_tmp2_, TRUE);
#line 33 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp3_ = _data10_->toolbar;
#line 33 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_signal_connect_data (_tmp3_, "popup-context-menu", (GCallback) __midori_window_toolbar____lambda25__gtk_toolbar_popup_context_menu, block10_data_ref (_data10_), (GClosureNotify) block10_data_unref, 0);
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp4_ = _data10_->toolbar;
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp5_ = _g_object_ref0 ((GtkWidget*) _tmp4_);
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_object_unref0 (self->priv->_toolbar);
#line 35 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		self->priv->_toolbar = _tmp5_;
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		block10_data_unref (_data10_);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_data10_ = NULL;
#line 1654 "midori-window.c"
	}
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp6_ = self->priv->_toolbar;
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	result = _tmp6_;
#line 37 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return result;
#line 1662 "midori-window.c"
}


const gchar* midori_window_get_actions (MidoriWindow* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = self->priv->_actions;
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	result = _tmp0_;
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return result;
#line 1677 "midori-window.c"
}


void midori_window_set_actions (MidoriWindow* self, const gchar* value) {
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (self != NULL);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (g_strcmp0 (value, midori_window_get_actions (self)) != 0) {
#line 1686 "midori-window.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp0_ = value;
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_g_free0 (self->priv->_actions);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		self->priv->_actions = _tmp1_;
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_object_notify_by_pspec ((GObject *) self, midori_window_properties[MIDORI_WINDOW_ACTIONS_PROPERTY]);
#line 1699 "midori-window.c"
	}
}


static const gchar* midori_window_get_extra_actions (MidoriWindow* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = self->priv->_extra_actions;
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	result = _tmp0_;
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return result;
#line 1715 "midori-window.c"
}


static void midori_window_set_extra_actions (MidoriWindow* self, const gchar* value) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (self != NULL);
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = value;
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_free0 (self->priv->_extra_actions);
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self->priv->_extra_actions = _tmp1_;
#line 1732 "midori-window.c"
}


GtkWidget* midori_window_get_contents (MidoriWindow* self) {
	GtkWidget* result;
	GtkWidget* _tmp0_;
#line 48 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 49 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = self->priv->_contents;
#line 49 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	result = _tmp0_;
#line 49 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return result;
#line 1747 "midori-window.c"
}


void midori_window_set_contents (MidoriWindow* self, GtkWidget* value) {
	GtkWidget* _tmp0_;
	GtkWidget* _tmp3_;
	GtkWidget* _tmp4_;
	GtkWidget* _tmp5_;
	GtkBox* _tmp6_;
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (self != NULL);
#line 51 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = self->priv->_contents;
#line 51 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (_tmp0_ != NULL) {
#line 1763 "midori-window.c"
		GtkBox* _tmp1_;
		GtkWidget* _tmp2_;
#line 52 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp1_ = self->priv->box;
#line 52 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp2_ = self->priv->_contents;
#line 52 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		gtk_container_remove ((GtkContainer*) _tmp1_, _tmp2_);
#line 1772 "midori-window.c"
	}
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp3_ = value;
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_object_unref0 (self->priv->_contents);
#line 53 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self->priv->_contents = _tmp4_;
#line 54 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp5_ = self->priv->_contents;
#line 54 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	gtk_widget_show (_tmp5_);
#line 55 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp6_ = self->priv->box;
#line 55 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (_tmp6_ != NULL) {
#line 1790 "midori-window.c"
		GtkBox* _tmp7_;
		GtkWidget* _tmp8_;
#line 56 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp7_ = self->priv->box;
#line 56 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp8_ = self->priv->_contents;
#line 56 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		gtk_box_pack_end (_tmp7_, _tmp8_, TRUE, TRUE, (guint) 0);
#line 1799 "midori-window.c"
	}
#line 50 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_object_notify_by_pspec ((GObject *) self, midori_window_properties[MIDORI_WINDOW_CONTENTS_PROPERTY]);
#line 1803 "midori-window.c"
}


gboolean midori_window_get_show_menubar (MidoriWindow* self) {
	gboolean result;
	gboolean _tmp0_;
#line 63 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 63 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = self->priv->_show_menubar;
#line 63 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	result = _tmp0_;
#line 63 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return result;
#line 1818 "midori-window.c"
}


void midori_window_set_show_menubar (MidoriWindow* self, gboolean value) {
#line 63 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (self != NULL);
#line 63 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (midori_window_get_show_menubar (self) != value) {
#line 1827 "midori-window.c"
		gboolean _tmp0_;
#line 63 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp0_ = value;
#line 63 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		self->priv->_show_menubar = _tmp0_;
#line 63 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_object_notify_by_pspec ((GObject *) self, midori_window_properties[MIDORI_WINDOW_SHOW_MENUBAR_PROPERTY]);
#line 1835 "midori-window.c"
	}
}


static void g_cclosure_user_marshal_BOOLEAN__OBJECT_OBJECT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT_OBJECT) (gpointer data1, gpointer arg_1, gpointer arg_2, gpointer data2);
	register GMarshalFunc_BOOLEAN__OBJECT_OBJECT callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	gboolean v_return;
	cc = (GCClosure *) closure;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (return_value != NULL);
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (n_param_values == 3);
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		data1 = closure->data;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		data2 = param_values->data[0].v_pointer;
#line 1858 "midori-window.c"
	} else {
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		data1 = param_values->data[0].v_pointer;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		data2 = closure->data;
#line 1864 "midori-window.c"
	}
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	callback = (GMarshalFunc_BOOLEAN__OBJECT_OBJECT) (marshal_data ? marshal_data : cc->callback);
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	v_return = callback (data1, g_value_get_object (param_values + 1), g_value_get_object (param_values + 2), data2);
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_value_set_boolean (return_value, v_return);
#line 1872 "midori-window.c"
}


static void _midori_window___lambda26_ (MidoriWindow* self, GParamSpec* pspec) {
#line 246 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_return_if_fail (pspec != NULL);
#line 246 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	midori_window_update_toolbar (self);
#line 1881 "midori-window.c"
}


static void __midori_window___lambda26__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 246 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_midori_window___lambda26_ ((MidoriWindow*) self, pspec);
#line 1888 "midori-window.c"
}


static GObject * midori_window_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	MidoriWindow * self;
	GtkVBox* _tmp0_;
	GtkBox* _tmp1_;
	GtkBox* _tmp2_;
	GList* _tmp3_;
	GtkWidget* _tmp7_;
	GtkWidget* _tmp8_;
	GList* _tmp12_;
	GtkWidget* _tmp16_;
	const gchar* _tmp19_;
#line 228 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	parent_class = G_OBJECT_CLASS (midori_window_parent_class);
#line 228 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 228 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, MIDORI_TYPE_WINDOW, MidoriWindow);
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = (GtkVBox*) gtk_vbox_new (FALSE, 0);
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_object_ref_sink (_tmp0_);
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_object_unref0 (self->priv->box);
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self->priv->box = (GtkBox*) _tmp0_;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = self->priv->box;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	gtk_widget_show ((GtkWidget*) _tmp1_);
#line 231 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp2_ = self->priv->box;
#line 231 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp2_);
#line 232 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp3_ = self->priv->toolbars;
#line 1929 "midori-window.c"
	{
		GList* toolbar_collection = NULL;
		GList* toolbar_it = NULL;
#line 232 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		toolbar_collection = _tmp3_;
#line 232 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		for (toolbar_it = toolbar_collection; toolbar_it != NULL; toolbar_it = toolbar_it->next) {
#line 1937 "midori-window.c"
			GtkWidget* toolbar = NULL;
#line 232 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
			toolbar = (GtkWidget*) toolbar_it->data;
#line 1941 "midori-window.c"
			{
				GtkWidget* _tmp4_;
#line 233 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp4_ = toolbar;
#line 233 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GTK_TYPE_MENU_BAR)) {
#line 1948 "midori-window.c"
					GtkBox* _tmp5_;
					GtkWidget* _tmp6_;
#line 234 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp5_ = self->priv->box;
#line 234 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp6_ = toolbar;
#line 234 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					gtk_box_pack_start (_tmp5_, _tmp6_, FALSE, FALSE, (guint) 0);
#line 1957 "midori-window.c"
				}
			}
		}
	}
#line 236 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp7_ = midori_window_get_toolbar (self);
#line 236 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp8_ = _tmp7_;
#line 236 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, GTK_TYPE_TOOLBAR)) {
#line 1968 "midori-window.c"
		GtkBox* _tmp9_;
		GtkWidget* _tmp10_;
		GtkWidget* _tmp11_;
#line 237 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp9_ = self->priv->box;
#line 237 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp10_ = midori_window_get_toolbar (self);
#line 237 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp11_ = _tmp10_;
#line 237 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		gtk_box_pack_start (_tmp9_, _tmp11_, FALSE, FALSE, (guint) 0);
#line 1980 "midori-window.c"
	}
#line 238 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp12_ = self->priv->toolbars;
#line 1984 "midori-window.c"
	{
		GList* toolbar_collection = NULL;
		GList* toolbar_it = NULL;
#line 238 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		toolbar_collection = _tmp12_;
#line 238 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		for (toolbar_it = toolbar_collection; toolbar_it != NULL; toolbar_it = toolbar_it->next) {
#line 1992 "midori-window.c"
			GtkWidget* toolbar = NULL;
#line 238 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
			toolbar = (GtkWidget*) toolbar_it->data;
#line 1996 "midori-window.c"
			{
				GtkWidget* _tmp13_;
#line 239 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				_tmp13_ = toolbar;
#line 239 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GTK_TYPE_MENU_BAR)) {
#line 2003 "midori-window.c"
					GtkBox* _tmp14_;
					GtkWidget* _tmp15_;
#line 240 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp14_ = self->priv->box;
#line 240 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					_tmp15_ = toolbar;
#line 240 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
					gtk_box_pack_start (_tmp14_, _tmp15_, FALSE, FALSE, (guint) 0);
#line 2012 "midori-window.c"
				}
			}
		}
	}
#line 242 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp16_ = self->priv->_contents;
#line 242 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (_tmp16_ != NULL) {
#line 2021 "midori-window.c"
		GtkBox* _tmp17_;
		GtkWidget* _tmp18_;
#line 243 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp17_ = self->priv->box;
#line 243 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		_tmp18_ = self->priv->_contents;
#line 243 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		gtk_box_pack_end (_tmp17_, _tmp18_, TRUE, TRUE, (guint) 0);
#line 2030 "midori-window.c"
	}
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp19_ = self->priv->_actions;
#line 244 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	if (g_strcmp0 (_tmp19_, "") != 0) {
#line 245 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		midori_window_update_toolbar (self);
#line 2038 "midori-window.c"
	}
#line 246 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_signal_connect_object ((GObject*) self, "notify::actions", (GCallback) __midori_window___lambda26__g_object_notify, self, 0);
#line 228 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	return obj;
#line 2044 "midori-window.c"
}


static void midori_window_class_init (MidoriWindowClass * klass) {
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	midori_window_parent_class = g_type_class_peek_parent (klass);
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_type_class_add_private (klass, sizeof (MidoriWindowPrivate));
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_midori_window_get_property;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_midori_window_set_property;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	G_OBJECT_CLASS (klass)->constructor = midori_window_constructor;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	G_OBJECT_CLASS (klass)->finalize = midori_window_finalize;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), MIDORI_WINDOW_TOOLBAR_PROPERTY, midori_window_properties[MIDORI_WINDOW_TOOLBAR_PROPERTY] = g_param_spec_object ("toolbar", "toolbar", "toolbar", GTK_TYPE_WIDGET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), MIDORI_WINDOW_ACTIONS_PROPERTY, midori_window_properties[MIDORI_WINDOW_ACTIONS_PROPERTY] = g_param_spec_string ("actions", "actions", "actions", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), MIDORI_WINDOW_CONTENTS_PROPERTY, midori_window_properties[MIDORI_WINDOW_CONTENTS_PROPERTY] = g_param_spec_object ("contents", "contents", "contents", GTK_TYPE_WIDGET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), MIDORI_WINDOW_SHOW_MENUBAR_PROPERTY, midori_window_properties[MIDORI_WINDOW_SHOW_MENUBAR_PROPERTY] = g_param_spec_boolean ("show-menubar", "show-menubar", "show-menubar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	midori_window_signals[MIDORI_WINDOW_CONTEXT_MENU_SIGNAL] = g_signal_new ("context-menu", MIDORI_TYPE_WINDOW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_BOOLEAN__OBJECT_OBJECT, G_TYPE_BOOLEAN, 2, GTK_TYPE_WIDGET, GTK_TYPE_ACTION);
#line 2071 "midori-window.c"
}


static void midori_window_instance_init (MidoriWindow * self) {
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self->priv = MIDORI_WINDOW_GET_PRIVATE (self);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self->priv->_toolbar = NULL;
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp0_ = g_strdup ("");
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self->priv->_actions = _tmp0_;
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_tmp1_ = g_strdup ("");
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self->priv->_extra_actions = _tmp1_;
#line 44 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self->priv->box = NULL;
#line 47 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self->priv->_contents = NULL;
#line 63 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self->priv->_show_menubar = FALSE;
#line 2096 "midori-window.c"
}


static void midori_window_finalize (GObject * obj) {
	MidoriWindow * self;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, MIDORI_TYPE_WINDOW, MidoriWindow);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_object_unref0 (self->priv->_toolbar);
#line 40 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_free0 (self->priv->_actions);
#line 41 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_free0 (self->priv->_extra_actions);
#line 42 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	__g_list_free__g_object_unref0_0 (self->priv->action_groups);
#line 44 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_object_unref0 (self->priv->box);
#line 45 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	__g_list_free__g_object_unref0_0 (self->priv->toolbars);
#line 47 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	_g_object_unref0 (self->priv->_contents);
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	G_OBJECT_CLASS (midori_window_parent_class)->finalize (obj);
#line 2120 "midori-window.c"
}


GType midori_window_get_type (void) {
	static volatile gsize midori_window_type_id__volatile = 0;
	if (g_once_init_enter (&midori_window_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (MidoriWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) midori_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MidoriWindow), 0, (GInstanceInitFunc) midori_window_instance_init, NULL };
		GType midori_window_type_id;
		midori_window_type_id = g_type_register_static (GTK_TYPE_WINDOW, "MidoriWindow", &g_define_type_info, 0);
		g_once_init_leave (&midori_window_type_id__volatile, midori_window_type_id);
	}
	return midori_window_type_id__volatile;
}


static void _vala_midori_window_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	MidoriWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, MIDORI_TYPE_WINDOW, MidoriWindow);
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	switch (property_id) {
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		case MIDORI_WINDOW_TOOLBAR_PROPERTY:
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_value_set_object (value, midori_window_get_toolbar (self));
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		break;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		case MIDORI_WINDOW_ACTIONS_PROPERTY:
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_value_set_string (value, midori_window_get_actions (self));
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		break;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		case MIDORI_WINDOW_CONTENTS_PROPERTY:
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_value_set_object (value, midori_window_get_contents (self));
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		break;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		case MIDORI_WINDOW_SHOW_MENUBAR_PROPERTY:
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		g_value_set_boolean (value, midori_window_get_show_menubar (self));
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		break;
#line 2165 "midori-window.c"
		default:
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		break;
#line 2171 "midori-window.c"
	}
}


static void _vala_midori_window_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	MidoriWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, MIDORI_TYPE_WINDOW, MidoriWindow);
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
	switch (property_id) {
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		case MIDORI_WINDOW_ACTIONS_PROPERTY:
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		midori_window_set_actions (self, g_value_get_string (value));
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		break;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		case MIDORI_WINDOW_CONTENTS_PROPERTY:
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		midori_window_set_contents (self, g_value_get_object (value));
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		break;
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		case MIDORI_WINDOW_SHOW_MENUBAR_PROPERTY:
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		midori_window_set_show_menubar (self, g_value_get_boolean (value));
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		break;
#line 2199 "midori-window.c"
		default:
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/midori/midori-window.vala"
		break;
#line 2205 "midori-window.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



